@@ -132,6 +132,9 @@ class Pod(NamespacedResource):
         if rcstring == "Success" or ignore_rc:
             return stdout
 
+        if rcstring == "Failure":
+            raise ExecOnPodError(command=command, rc=-1, out="", err=error_channel)
+
         returncode = [
             int(cause["message"])
             for cause in error_channel["details"]["causes"]
